﻿using Common;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using RedisHelp;
using System;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Security.Cryptography;
using System.Text;
using System.Web;
using System.Web.Http;
using TGood.Xian.LogManager;
using ThoughtWorks.QRCode.Codec;
using WxPayAPI.Models;
using wxWebAPI.business;
using wxWebAPI.Common;
using wxWebAPI.Filters;
using wxWebAPI.Models;
using wxWebAPI.Models.cardapplet;

namespace WxPayAPI
{
    public class UserController : ApiController
    {
        /// <summary>
        /// app版本监测
        /// </summary>
        /// <param name="version">当前版本号</param>
        /// <returns>code返回码，data最新版本信息，error错误信息</returns>
        [HttpGet, HttpOptions]
        public JObject CheckAPPVersion(int version)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                APPVersion checkResult = chargeLogic.CheckAPPVersion(version);
                result.Add("code", 1);
                result.Add("data", JProperty.FromObject(checkResult));
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - CheckAPPVersion Error,version={version}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        /// <summary>
        /// 发送短信验证码
        /// </summary>
        /// <param name="requestInfo">PhoneNum:目标手机号码,RequestTime:请求发送验证码时间,MD5:计算出的md5值</param>
        /// <returns></returns>
        [HttpPost, HttpOptions]
        public JObject SendPIN([FromBody]PINInfo requestInfo)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                int sendResult = chargeLogic.SendPIN(requestInfo);
                switch (sendResult)
                {
                    case -1:
                        result.Add("code", -1);
                        result.Add("data", "sent more than maximum");
                        break;
                    case -2:
                        result.Add("code", -2);
                        result.Add("data", "sending interval is too short");
                        break;
                    case -3:
                        result.Add("code", -3);
                        result.Add("data", "md5 check is wrong");
                        break;
                    case 1:
                        result.Add("code", 1);
                        result.Add("data", "sending");
                        break;
                    default:
                        break;
                }
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - SendPIN Error,phoneNum={requestInfo.PhoneNum},RequestTime={requestInfo.RequestTime},MD5={requestInfo.MD5}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        /// <summary>
        /// 检查校验码是否正确，并返回设备标识和用户标识
        /// </summary>
        /// <param name="phoneNumCode">key为手机号码，value为验证码</param>
        /// <returns></returns>
        [HttpPost, HttpOptions]
        public JObject CheckPIN([FromBody]KeyValuePair<string, string> phoneNumCode)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                JObject checkResult = chargeLogic.CheckPIN(phoneNumCode);
                if (checkResult != null)
                {
                    result.Add("code", 1);
                    result.Add("data", checkResult);
                }
                else
                {
                    result.Add("code", 0);
                    //result.Add("data", null);
                }
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - CheckPIN Error,PhoneNum={phoneNumCode.Key},PIN={phoneNumCode.Value}。", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }

            return result;
        }

        [HttpPost, HttpOptions]
        public JObject CheckAndUpdatePhone([FromBody]CheckPin checkpin)
        {
            JObject result = new JObject();
            try
            {
                if (string.IsNullOrEmpty(WechatUtility.GetOpenIDByUserToken(checkpin.usertoken)))
                {
                    result.Add("code", -10);
                    result.Add("error", "Token过期，请重新登陆");
                    return result;
                }
                var payLogic = new PayLogic();
                bool update = payLogic.CheckAndUpdatePhone(checkpin);
                if (update == true)
                {
                    result.Add("code", 1);
                    result.Add("data", "更改手机号成功");
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", "更改手机号失败");
                }
            }
            catch (Exception e)
            {
                result.Add("code", 0);
                result.Add("data", $"更改手机号出错+{e.ToString()}");
            }
            return result;
        }

        /// <summary>
        /// APP登录
        /// </summary>
        /// <param name="login">DeviceID为移动设备唯一标识</param>
        /// <returns></returns>
        [HttpPost, HttpOptions]
        public JObject APPLogin([FromBody]APP_Login login)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                JObject loginResult = chargeLogic.APPLogin(login);
                if (loginResult != null)
                {
                    result.Add("code", 1);
                    result.Add("data", loginResult);
                }
                else
                {
                    result.Add("code", 0);
                    //result.Add("data", null);
                }
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - APPLogin Error,login.PhoneNum={login.PhoneNum},login.DeviceID={login.DeviceID},login.MD5={login.MD5}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }

            return result;
        }

        /// <summary>
        /// 根据电话号码获取用户信息，包括账户余额
        /// </summary>
        /// <param name="userToken">手机号码</param>
        /// <returns></returns>
        [HttpGet, HttpOptions]

        public JObject GetAPPUser(string userToken)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                var user = chargeLogic.GetAPPUser(userToken);
                result.Add("code", 1);
                result.Add("data", JProperty.FromObject(user));
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - GetAPPUser Error,userToken={userToken}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        [HttpGet, HttpOptions]
        public JObject GetAPPUserBalance(string userToken)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                int? userBalance = chargeLogic.GetAPPUserBalance(userToken);
                if (userBalance.HasValue)
                {
                    result.Add("code", 1);
                    result.Add("data", userBalance.Value);
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", 0);
                }
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - GetAPPUserBalance Error,userToken={userToken}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        [HttpPost, HttpOptions]
        public JObject UpdateAPPUser([FromBody] APP_User user, string userToken)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                APP_User updateResult = chargeLogic.UpdateAPPUser(user, userToken);
                if (updateResult == null)
                {
                    result.Add("code", 0);
                    result.Add("data", null);
                }
                else
                {
                    result.Add("code", 1);
                    result.Add("data", JProperty.FromObject(updateResult));
                }
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - UpdateAPPUser Error,userToken={userToken},user.loginid={user.loginid}," +
                                            $"user.nickname={user.nickname},user.sex={user.sex},user.birthday={user.birthday}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        [HttpPost, HttpOptions]
        public JObject UploadAPPUserProfile([FromBody] UserProfile userProfile, string userToken)
        {
            JObject result = new JObject();
            try
            {
                string imagepath = string.Empty;
                var chargeLogic = new ChargeLogic();
                Boolean uploadResult = chargeLogic.UploadAPPUserProfile(userProfile, userToken,ref imagepath);
                if (uploadResult)
                {
                    result.Add("code", 1);
                }
                else
                {
                    result.Add("code", 0);
                }
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - UploadAPPUserProfile Error,userToken={userToken}, userProfile={userProfile}", ex);
                result.RemoveAll();
                result.Add("code", 0);
            }
            return result;
        }

        /// <summary>
        /// 获取用户历史充值记录，返回小于minID的20条记录，首次请求minID不传或传0，后继传上次获取到的对象中最小的id
        /// </summary>
        /// <param name="userToken">用户标示</param>
        /// <param name="minID">最小ID</param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject GetHistoryRecharge(string userToken, int minID = 0)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                IEnumerable<Recharge> historyRechargeList = chargeLogic.GetHistoryRecharge(userToken, minID);
                if (historyRechargeList != null)
                {
                    result.Add("code", 1);
                    result.Add("data", JProperty.FromObject(historyRechargeList));
                    //当前订单中最小id
                    result.Add("minid", historyRechargeList.Any() ? historyRechargeList.Last().id : 0);
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", null);
                }
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"GetHistoryRecharge userToken={userToken}", ex);
                result.RemoveAll();
                result.Add("code", 0);
#if DEBUG
                result.Add("error", ex.ToString());
#endif
            }
            return result;
        }

        [HttpGet, HttpOptions]
        [TokenFilter]
        public JObject GetChargingDevice(string userToken)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                List<string> deviceCode = chargeLogic.NewGetChargingDevice(userToken);
                if (deviceCode != null)
                {
                    result.Add("code", 1);
                }
                else
                {
                    result.Add("code", 0);
                }

                result.Add("data", JProperty.FromObject(deviceCode));
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - APPStartCharge Error,userToken={userToken}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        [HttpGet, HttpOptions]
        public JObject APPStartCharge(string userToken, string deviceCode,string nickname)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                result = chargeLogic.StartCharge(userToken, deviceCode,nickname);
            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - APPStartCharge Error,deviceCode={deviceCode}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        [HttpGet, HttpOptions]
        [TokenFilter]
        public JObject APPStopCharge(string userToken, string deviceCode)
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                var stopResult = chargeLogic.APPStopCharge(userToken, deviceCode);

                if (stopResult == true)
                {
                    result.Add("code", 1);
                    result.Add("data", "此处可能返回一些其他信息");
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", null);
                }

            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - APPStartCharge Error,userToken={userToken}, deviceCode={deviceCode}", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        [HttpGet, HttpOptions]
        public JObject GetShareInfo()
        {
            JObject result = new JObject();
            try
            {
                var chargeLogic = new ChargeLogic();
                var info = chargeLogic.GetShareInfo();

                if (info != null)
                {
                    result.Add("code", 1);
                    result.Add("data", JProperty.FromObject(info));
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", null);
                }

            }
            catch (Exception ex)
            {
                LogEvent.WebAPILoger.Error($"OrdersController - GetShareInfo Error", ex);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("error", ex.ToString());
            }
            return result;
        }

        /// <summary>
        /// decrypt phone number
        /// </summary>
        /// <param name="userToken"></param>
        /// <param name="encryptedData"></param>
        /// <param name="iv"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        [TokenFilter]
        public JObject DecryptPhoneNumber([FromUri]string userToken, string encryptedData, string iv, string nickname)
        {
            JObject value = new JObject();
            try
            {
                //get session_key according to token
                var sessionKey = WechatUtility.GetSessionKey(userToken);

                //get byte[] based on Base64 encoding
                byte[] encrypted64 = Convert.FromBase64String(encryptedData);
                byte[] key64 = Convert.FromBase64String(sessionKey);
                byte[] iv64 = Convert.FromBase64String(iv);

                //get decrypted data
                value = JObject.Parse(UserLogic.AESDecrypt(key64, iv64, encrypted64));

                //get phone number
                string phoneNumber = value.GetValue("phoneNumber").ToString();

                if (!string.IsNullOrEmpty(phoneNumber))
                {
                    new UserLogic().BindingPhoneNumber(phoneNumber, userToken, nickname);
                }
                value.RemoveAll();
                value.Add("phoneNumber", phoneNumber);
            }
            catch (Exception e)
            {

                LogEvent.WebAPILoger.Error($@"保存手机号失败！nickname={nickname},e={e}");
            }
            return value;
        }

        [HttpGet, HttpOptions]
        [TokenFilter]
        public JObject GetPhoneNumber(string userToken)
        {
            var result = new JObject();
            string phoneNumber = "";
            try
            {
                if (string.IsNullOrEmpty(WechatUtility.GetOpenIDByUserToken(userToken)))
                {
                    result.Add("code", -10);
                    result.Add("error", "Token过期，请重新登陆");
                    return result;
                }
                UserLogic ul = new UserLogic();
                phoneNumber = ul.GetPhoneNumber(userToken);
            }
            catch (Exception e)
            {
                result.Add("code", 0);
                result.Add("error", e.ToString());
                LogEvent.WebAPILoger.Error("获取用户手机号异常");
            }
            result.Add("phoneNumber", phoneNumber);

            return result;
        }

        /// <summary>
        /// 添加收藏
        /// </summary>
        /// <param name="usertoken"></param>
        /// <param name="stationid"></param>
        /// <param name="devicecode"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject PostCollect(string usertoken, string stationid = null, string devicecode = null)
        {
            JObject result = new JObject();
            try
            {
                if (string.IsNullOrEmpty(WechatUtility.GetOpenIDByUserToken(usertoken)))
                {
                    result.Add("code", -10);
                    result.Add("error", "Token过期，请重新登陆");
                    return result;
                }
                CollectLogic cl = new CollectLogic();
                bool save = cl.PostCollect(usertoken, stationid, devicecode);
                if (save == true)
                {
                    result.Add("code", 1);
                    result.Add("data", "success");
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", "保存失败");
                }
            }
            catch (Exception e)
            {
                result.Add("code", 0);
                result.Add("data", e.ToString());
                LogEvent.WebAPILoger.Error("保存收藏信息失败", e);
            }
            return result;
        }

        /// <summary>
        /// 获取收藏的终端的信息
        /// </summary>
        /// <param name="usertoken"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject GetCollectGunInfo(string usertoken)
        {
            JObject result = new JObject();
            try
            {
                if (string.IsNullOrEmpty(WechatUtility.GetOpenIDByUserToken(usertoken)))
                {
                    result.Add("code", -10);
                    result.Add("error", "Token过期，请重新登陆");
                    return result;
                }
                CollectLogic cl = new CollectLogic();
                List<GunStatusInfo> guninfos = cl.GetCollectGunInfo(usertoken);
                if (guninfos.Any())
                {
                    result.Add("code", 1);
                    result.Add("data", JProperty.FromObject(guninfos));
                }
                else
                {
                    result.Add("code", 1);
                    result.Add("data", "无数据");
                }
            }
            catch (Exception e)
            {
                result.Add("code", 0);
                result.Add("error", e.ToString());
                LogEvent.WebAPILoger.Error("获取收藏终端信息失败", e);
            }
            return result;
        }
        /// <summary>
        /// 获取收藏的站点的信息
        /// </summary>
        /// <param name="usertoken"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject GetCollectInfo(string usertoken)
        {
            JObject result = new JObject();
            try
            {
                if (string.IsNullOrEmpty(WechatUtility.GetOpenIDByUserToken(usertoken)))
                {
                    result.Add("code", -10);
                    result.Add("error", "Token过期，请重新登陆");
                    return result;
                }
                CollectLogic cl = new CollectLogic();
                List<LCO_Station> station = cl.GetCollectInfo(usertoken);
                if (station != null)
                {
                    result.Add("code", 1);
                    result.Add("data", JProperty.FromObject(station));
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", "无数据");
                }
            }
            catch (Exception e)
            {
                result.Add("code", 0);
                result.Add("error", e.ToString());
                LogEvent.WebAPILoger.Error("获取收藏场站信息失败", e);
            }
            return result;
        }
        /// <summary>
        /// 取消收藏
        /// </summary>
        /// <param name="usertoken"></param>
        /// <param name="devicecode"></param>
        /// <param name="stationid"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject DeleteCollect(string usertoken, string devicecode = null, string stationid = null)
        {
            JObject result = new JObject();
            try
            {
                if (string.IsNullOrEmpty(WechatUtility.GetOpenIDByUserToken(usertoken)))
                {
                    result.Add("code", -10);
                    result.Add("error", "Token过期，请重新登陆");
                    return result;
                }
                CollectLogic cl = new CollectLogic();
                bool delete = cl.DeleteCollect(usertoken, devicecode, stationid);
                if (delete == true)
                {
                    result.Add("code", 1);
                    result.Add("data", "success");
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", "删除失败");
                }
            }
            catch (Exception e)
            {

                result.Add("code", 0);
                result.Add("data", e.ToString());
                LogEvent.WebAPILoger.Error("删除收藏信息失败", e);
            }
            return result;
        }
        /// <summary>
        /// 获取全部车辆品牌
        /// </summary>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject GetTotalCarsCompany()
        {
            string result = string.Empty;
            JObject resoonse = new JObject();
            try
            {
                UserLogic userlogic = new UserLogic();
                resoonse.Add("code", 1);
                resoonse.Add("data",JProperty.FromObject(userlogic.GetTotalCarsCompany()));
            }
            catch (Exception e) {

                resoonse.Add("0");
                resoonse.Add("data", e.ToString());
            }
            return resoonse;
        }
        /// <summary>
        /// 根据车牌子找车类型
        /// </summary>
        /// <param name="carCompany"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject getCarTypeByCarCompany(string carCompany)
        {
            JObject result = new JObject();
            try
            {
                UserLogic user = new UserLogic();
                List<dynamic> cars = user.getCarTypeByCarCompany(carCompany);
                if (cars.Any())
                {
                    result.Add("code", 1);
                    result.Add("data", JProperty.FromObject(cars));
                }
                else
                {

                    result.Add("code", 0);
                    result.Add("data", "查无数据");
                }

            }
            catch (Exception e)
            {
                result.Add("code", 0);
                result.Add("data", $"出错原因{e}");
            }
            return result;
        }

        /// <summary>
        /// 绑定车型
        /// </summary>
        /// <param name="carsCompany"></param>
        /// <param name="carType"></param>
        /// <param name="usertoken"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject bindCar(string usertoken, string carsCompany, string carType, int endurance, string carPlate = null,string productionDate=null)
        {
            JObject result = new JObject();
            try
            {
                UserLogic user = new UserLogic();
                bool insert = user.bindCar(carsCompany, carType, usertoken, carPlate, endurance,productionDate);
                if (insert == true)
                {
                    result.Add("code", 1);
                    result.Add("data", "success");
                }
                else {
                    result.Add("code", 0);
                    result.Add("data", "fail");
                }
            }
            catch (Exception e)
            {
                result.Add("code", -10);
                result.Add("data", e.ToString());
            }
            return result;
        }

        [HttpPost, HttpOptions]
        public JObject UploadImage()
        {

            var result = new JObject();

            var path1 = AppDomain.CurrentDomain.BaseDirectory;

            var files = HttpContext.Current.Request.Files;


            var path = AppDomain.CurrentDomain.BaseDirectory + @"CarsImages\";

            try
            {
                foreach (string key in files.AllKeys)
                {
                    HttpPostedFile file = files[key];
                    if (file.ContentLength > 0)
                    {
                        if (!Directory.Exists(path))
                            Directory.CreateDirectory(path);
                        file.SaveAs(path + file.FileName);
                    }
                    string imageUrl = "/CarsImages/" + file.FileName;
                    using (IDbConnection connection = WechatUtility.CreateDBConnection())
                    {
                        string sql = $"UPDATE ev_brand SET brandpicture  ='{file.FileName}'WHERE brand = '{file.FileName.Substring(0, file.FileName.Length - 4)}'";

                    }

                    result.Add("code", 1);
                    result.Add("description", "上传成功!");
                    result.Add("imageUrl", imageUrl);
                }
            }
            catch (Exception e)
            {
                LogEvent.WebAPILoger.Error("FaultController - UploadImage", e);
                result.RemoveAll();
                result.Add("code", 0);
                result.Add("description", "上传失败!");
                result.Add("error", e.InnerException.Message);
            }
            return result;
        }

        [HttpGet, HttpOptions]
        public JObject GetAlarmInfo() {
            JObject result = new JObject();
            try
            {
                UserLogic user = new UserLogic();
                var message =  user.GetAlarmInfo();
                if (message!= null&&message.Content!=null)
                {
                    result.Add("code", 1);
                    result.Add("data",JProperty.FromObject(message));
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", "null");
                }
            }
            catch (Exception ex)
            {
                result.Add("code", 0);
                result.Add("data", $"fail,{ex}");
            }
            return result;
        }


        /// <summary>
        /// 获取近期使用的站点的信息
        /// </summary>
        /// <param name="usertoken"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject GetComuseInfo(string usertoken)
        {
            JObject result = new JObject();
            try
            {
                if (string.IsNullOrEmpty(WechatUtility.GetOpenIDByUserToken(usertoken)))//断点
                {
                    result.Add("code", -10);
                    result.Add("error", "Token过期，请重新登陆");
                    return result;
                }
                CollectLogic cl = new CollectLogic();
                List<LCO_Station> station = cl.GetComuseInfo(usertoken);//断点
                if (station != null)
                {
                    result.Add("code", 1);
                    result.Add("data", JProperty.FromObject(station));
                }
                else
                {
                    result.Add("code", 0);
                    result.Add("data", "无数据");
                }
            }
            catch (Exception e)
            {
                result.Add("code", 0);
                result.Add("error", e.ToString());
                LogEvent.WebAPILoger.Error("获取近期使用场站信息失败", e);
            }
            return result;
        }

        /// <summary>
        /// 获取近期使用的终端的信息
        /// </summary>
        /// <param name="usertoken"></param>
        /// <returns></returns>
        [HttpGet, HttpOptions]
        public JObject GetComuseGunInfo(string usertoken)
        {
            JObject result = new JObject();
            try
            {
                if (string.IsNullOrEmpty(WechatUtility.GetOpenIDByUserToken(usertoken)))//断点
                {
                    result.Add("code", -10);
                    result.Add("error", "Token过期，请重新登陆");
                    return result;
                }
                CollectLogic cl = new CollectLogic();
                List<GunStatusInfo> guninfos = cl.GetComuseGunInfo(usertoken); //断点
                if (guninfos.Any())
                {
                    result.Add("code", 1);
                    result.Add("data", JProperty.FromObject(guninfos));
                }
                else
                {
                    result.Add("code", 1);
                    result.Add("data", "无数据");
                }
            }
            catch (Exception e)
            {
                result.Add("code", 0);
                result.Add("error", e.ToString());
                LogEvent.WebAPILoger.Error("获取近期使用终端信息失败", e);
            }
            return result;
        }

    }
}
